==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/man/genotypeSummary.Rd <==
\name{genotypeSummary}
\alias{genotypeSummary}
%\alias{print.GeneticsBaseSummary}
\title{print the summary of genotypes sorted by markers}
\description{
  print the summary of genotypes sorted by markers
}
\usage{
genotypeSummary(object, 
                by = NULL, 
                confidence = 0.95, 
                alpha = 1 - confidence, 
                show = TRUE, 
                HWE.method = c("simulate", "exact"), 
                simulate.p.value = TRUE, 
                B = 10000, 
                verbose = FALSE, 
                includeOverall = FALSE, 
                omitRepeats = TRUE, 
                founderOnly = TRUE, 
                ...)

%print.GeneticsBaseSummary(x, digits = 3, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{geneSet object }
  \item{by}{ optional column name, by which the summary is
    desired. Default is NULL. }
  \item{confidence}{ confidence intervals of Genotype frequencies within
    each marker (default is 95\%) }
  \item{alpha}{ Type -1 error rate = (1- confidence) }
  \item{show}{ No longer used }
  \item{HWE.method}{ Method to be used for Hardy-Weinberg Equilibrium
    Significance Test, exact or simulate }
  \item{simulate.p.value}{No longer used }
  \item{B}{No longer used }
  \item{verbose}{No longer used}
  \item{includeOverall}{logical value (TRUE/FALSE) indicating whether
    overall summary is also needed, default = FALSE }
  \item{omitRepeats}{ logical value (TRUE/FALSE) indicating whether
    Gene name and marker name should be printed repeatedly for each Genotype, default = TRUE }
  \item{founderOnly}{ logical value (TRUE/FALSE) indicating whether
    founder information should be extracted from the geneSet object, default = TRUE }
  %\item{x}{ object of class 'genotypeSummary'  }
  %\item{digits}{ number of digits to be printed in summary }
  \item{\dots}{any further arguments to print}
}
\details{ We can print the genotypeSummary on screen, or save in .html
  format or .tex format}
\author{Nitin Jain \email{nitin.jain@pfizer.com} }
\examples{
library(GeneticsBase)
data(CAMP)

temp <- genotypeSummary(CAMP)

print(temp)
txt(temp, filename="genotypeSummary.txt")
html(temp, filename="genotypeSummary.html")
latex(temp, filename="genotypeSummary.tex")

}
\keyword{ misc }% at least one, from doc/KEYWORDS

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/man/genotypeSummary.Rd <==
\name{genotypeSummary}
\alias{genotypeSummary}
%\alias{print.GeneticsBaseSummary}
\title{print the summary of genotypes sorted by markers}
\description{
  print the summary of genotypes sorted by markers
}
\usage{
genotypeSummary(object, 
                by = NULL, 
                confidence = 0.95, 
                alpha = 1 - confidence, 
                show = TRUE, 
                HWE.method = c("simulate", "exact"), 
                simulate.p.value = TRUE, 
                B = 10000, 
                verbose = FALSE, 
                includeOverall = FALSE, 
                omitRepeats = TRUE, 
                founderOnly = FALSE, 
                ...)

%print.GeneticsBaseSummary(x, digits = 3, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{object}{geneSet object }
  \item{by}{ optional column name, by which the summary is
    desired. Default is NULL. }
  \item{confidence}{ confidence intervals of Genotype frequencies within
    each marker (default is 95\%) }
  \item{alpha}{ Type -1 error rate = (1- confidence) }
  \item{show}{ No longer used }
  \item{HWE.method}{ Method to be used for Hardy-Weinberg Equilibrium
    Significance Test, exact or simulate }
  \item{simulate.p.value}{No longer used }
  \item{B}{No longer used }
  \item{verbose}{No longer used}
  \item{includeOverall}{logical value (TRUE/FALSE) indicating whether
    overall summary is also needed, default = FALSE }
  \item{omitRepeats}{ logical value (TRUE/FALSE) indicating whether
    Gene name and marker name should be printed repeatedly for each Genotype, default = TRUE }
  \item{founderOnly}{ logical value (TRUE/FALSE) indicating whether
    founder information should be extracted from the geneSet object, default = FALSE }
  %\item{x}{ object of class 'genotypeSummary'  }
  %\item{digits}{ number of digits to be printed in summary }
  \item{\dots}{any further arguments to print}
}
\details{ We can print the genotypeSummary on screen, or save in .html
  format or .tex format}
\author{Nitin Jain \email{nitin.jain@pfizer.com} }
\examples{
library(GeneticsBase)
data(CAMP)

temp <- genotypeSummary(CAMP)

print(temp)
txt(temp, filename="genotypeSummary.txt")
html(temp, filename="genotypeSummary.html")
latex(temp, filename="genotypeSummary.tex")

}
\keyword{ misc }% at least one, from doc/KEYWORDS
